@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, Iterator, List, Optional
+from typing import Any, Iterator, List
 
 from jubeatools import song
 from jubeatools.formats.load_tools import make_folder_loader
@@ -23,8 +23,8 @@ load_folder = make_folder_loader("*.eve", load_file)
 
 def _load_eve(lines: List[str], file_path: Path, *, beat_snap: int = 240) -> song.Song:
     chart = make_chart_from_events(iter_events(lines), beat_snap=beat_snap)
-    dif = guess_difficulty(file_path.stem) or song.Difficulty.EXTREME
-    return song.Song(metadata=song.Metadata(), charts={dif: chart})
+    dif = guess_difficulty(file_path.stem)
+    return song.Song(metadata=song.Metadata(), charts={dif.value: chart})
 
 
 def iter_events(lines: List[str]) -> Iterator[Event]:
@@ -72,8 +72,8 @@ def parse_event(line: str) -> Event:
     return Event(tick, command, value)
 
 
-def guess_difficulty(filename: str) -> Optional[song.Difficulty]:
+def guess_difficulty(filename: str) -> song.Difficulty:
     try:
         return song.Difficulty(filename.upper())
     except ValueError:
-        return None
+        return song.Difficulty.EXTREME
