@@ -5,7 +5,7 @@ from hypothesis import given
 from jubeatools import song
 from jubeatools.formats.timemap import TimeMap
 from jubeatools.testutils import strategies as jbst
-from jubeatools.utils import group_by
+from jubeatools.utils import group_by, mixed_number_format
 
 
 @given(jbst.timing_info(with_bpm_changes=True), jbst.beat_time())
@@ -28,7 +28,9 @@ def naive_approach(beats: song.Timing, beat: song.BeatsTime) -> Fraction:
     grouped_by_time = group_by(beats.events, key=lambda e: e.time)
     for time, events in grouped_by_time.items():
         if len(events) > 1:
-            raise ValueError(f"Multiple BPMs defined on beat {time} : {events}")
+            raise ValueError(
+                f"Multiple BPMs defined on beat {mixed_number_format(time)} : {events}"
+            )
 
     sorted_events = sorted(beats.events, key=lambda e: e.time)
     first_event = sorted_events[0]
