@@ -216,7 +216,7 @@ hakus = partial(st.sets, beat_time())
 @st.composite
 def chart(
     draw: st.DrawFn,
-    timing_strat: st.SearchStrategy[Timing] = timing_info(),
+    timing_strat: st.SearchStrategy[Optional[Timing]] = timing_info(),
     hakus_strat: st.SearchStrategy[Optional[Set[BeatsTime]]] = st.none(),
     notes_strat: st.SearchStrategy[Iterable[Union[TapNote, LongNote]]] = notes(),
     level_strat: st.SearchStrategy[Union[int, Decimal]] = level(),
